componenttools.Parentage
========================

.. abjad-lineage:: abjad.tools.componenttools.Parentage.Parentage.Parentage

.. autoclass:: abjad.tools.componenttools.Parentage.Parentage.Parentage
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.component
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.containment_signature
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.depth
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.is_orphan
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.music
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.parent
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.parentage_signature
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.root
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.score_index
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.start_offset
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.storage_format
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.timespan
   :noindex:

.. autoattribute:: abjad.tools.componenttools.Parentage.Parentage.Parentage.tuplet_depth
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__add__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__contains__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__eq__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__ge__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__getitem__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__gt__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__le__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__len__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__lt__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__ne__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__radd__
   :noindex:

.. automethod:: abjad.tools.componenttools.Parentage.Parentage.Parentage.__repr__
   :noindex:
